Adds a single point at the origin `(0, 0)` – a centre reference for sparse themes where no crosshairs meet at the middle.
Examples
library(ggplot2)
ggplot() + coord_fixed() + add_circ() + add_origin_point()
Adds a single point at the origin `(0, 0)` – a centre reference for sparse themes where no crosshairs meet at the middle.
library(ggplot2)
ggplot() + coord_fixed() + add_circ() + add_origin_point()