Generates a `geom_segment()` layer containing small tick marks at north, south, east, and west. The layer can be added to any ggplot.
Examples
library(ggplot2)
ggplot() +
coord_fixed() +
add_ticks()
Generates a `geom_segment()` layer containing small tick marks at north, south, east, and west. The layer can be added to any ggplot.
library(ggplot2)
ggplot() +
coord_fixed() +
add_ticks()