Provides a list of annotation layers that mark 45, 135, 225, and 315 degrees on a unit circle.
Usage
degree_labs(display = circ_display(), colour = "black", units = NULL)Examples
library(ggplot2)
ggplot() +
coord_fixed() +
degree_labs()
Provides a list of annotation layers that mark 45, 135, 225, and 315 degrees on a unit circle.
degree_labs(display = circ_display(), colour = "black", units = NULL)library(ggplot2)
ggplot() +
coord_fixed() +
degree_labs()