Build a data frame of arrow segments representing mean direction vectors Length equals resultant_R; angle equals mean_dir
Source:R/headings.R
dot-heading_registry.RdBuild a data frame of arrow segments representing mean direction vectors Length equals resultant_R; angle equals mean_dir