Creates a list of annotation layers that render a circle with the requested radius and appearance. The returned list can be added directly to a ggplot.
Examples
library(ggplot2)
ggplot() +
coord_fixed() +
add_circ(radius = 1)
Creates a list of annotation layers that render a circle with the requested radius and appearance. The returned list can be added directly to a ggplot.
library(ggplot2)
ggplot() +
coord_fixed() +
add_circ(radius = 1)