Create geom layers for Cartesian track coordinates
Arguments
- data
Data frame that will be plotted.
- x_col
Name of the column mapped to the x aesthetic.
- y_col
Name of the column mapped to the y aesthetic.
- geom
Either a character vector (`"path"`/`"point"`) or a ggplot2 geom function (e.g. [ggplot2::geom_path]).
- mapping
Optional aesthetics created with [ggplot2::aes()].
- ...
Additional arguments passed on to the geom function.