Intersection helper for TrajSet trajectories
Source:R/circular_plotting.R
line_circle_intercept_traj.RdExtracts the first/last rows for a given id/time range and computes the intersection with the unit circle.
R/circular_plotting.R
line_circle_intercept_traj.RdExtracts the first/last rows for a given id/time range and computes the intersection with the unit circle.