Adds a named function to the heading rule registry so it can be called by
derive_headings via rule = "name". The function must
accept (df, cols, ...) and return a data frame with columns
id, time, and heading (radians).
Adds a named function to the heading rule registry so it can be called by
derive_headings via rule = "name". The function must
accept (df, cols, ...) and return a data frame with columns
id, time, and heading (radians).